@@ -1,5 +1,5 @@
 package Git::Raw::Odb;
-$Git::Raw::Odb::VERSION = '0.73';
+$Git::Raw::Odb::VERSION = '0.74';
 use strict;
 use warnings;
 
@@ -12,7 +12,7 @@ Git::Raw::Odb - Git object database class
 
 =head1 VERSION
 
-version 0.73
+version 0.74
 
 =head1 DESCRIPTION
 
@@ -65,6 +65,16 @@ disabled on alternate backends.
 Read an object from the database. Returns a L<Git::Raw::Odb::Object> or C<undef>
 if the object does not exist.
 
+=head2 write( $data, type )
+
+Write an object directly to the database. Returns the OID of the object. C<$type>
+should be one of the values as defines in the constants section of L<Git::Raw::Object>.
+
+=head2 hash( $data, $type )
+
+Determine the object-ID (sha1 hash) of C<$data>. C<$type> should be one of the values
+as defined in the constants section of L<Git::Raw::Object>.
+
 =head1 AUTHOR
 
 Jacques Germishuys <jacquesg@striata.com>
